@@ -96,6 +96,8 @@ for color in y_hex_colors1.keys():
             files.append(os.path.join(theme, "gtk-2.0", "menubar-toolbar", "gtkrc"))
             files.append(os.path.join(theme, "metacity-1", "metacity-theme-2.xml"))
             files.append(os.path.join(theme, "metacity-1", "metacity-theme-3.xml"))
+            files.append(os.path.join(theme, "libadwaita-1.5", "defaults-light.css"))
+            files.append(os.path.join(theme, "libadwaita-1.5", "defaults-dark.css"))
             for file in files:
                 if os.path.exists(file):
                     for accent in Y_HEX_ACCENT1:
@@ -130,3 +132,10 @@ for color in y_hex_colors1.keys():
 
 # Files
 os.system("cp -R files/* ./")
+
+# Fixes for accent-color
+
+# The brown is too orange so libAdwaita uses orange instead of sand.
+os.system(f"sed -i '/define-color accent_color/ s/aa876a/c8ac69/' usr/share/themes/Mint-L-Brown/gtk-3.0/gtk.css")
+os.system(f"sed -i '/define-color accent_color/ s/aa876a/c8ac69/' usr/share/themes/Mint-L-Dark-Brown/gtk-3.0/gtk.css")
+os.system(f"sed -i '/define-color accent_color/ s/aa876a/c8ac69/' usr/share/themes/Mint-L-Dark-Brown/gtk-3.0/gtk-dark.css")
